@@ -4,10 +4,13 @@ import binascii
 import base58
 import base64
 import requests
+import nest_asyncio
 from coincurve.keys import PrivateKey
 from coincurve._libsecp256k1 import ffi
 
 
+nest_asyncio.apply()
+
 class CenterIdentity:
     def __init__(self, wif, username, url_prefix=None):
 
